You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@apr.apache.org by Thom May <th...@planetarytramp.net> on 2002/03/17 22:10:15 UTC

Renames Pending - apr_implode_time

Hi, here are the patches for apr and apr-utils to rename apr_implode_time to
apr_time_exp_get.
Cheers,
-Thom


Index: renames_pending
===================================================================
RCS file: /home/cvspublic/apr/renames_pending,v
retrieving revision 1.4
diff -u -u -3 -r1.4 renames_pending
--- renames_pending	6 Mar 2002 20:29:39 -0000	1.4
+++ renames_pending	17 Mar 2002 20:27:12 -0000
@@ -1,6 +1,5 @@
 Symbol renames for APR 
 
-apr_time_exp_get                 from apr_implode_time
 apr_time_exp_gmt                 from apr_explode_gmt
 apr_time_exp_lt                  from apr_explode_localtime
 apr_time_exp_tz                  from apr_explode_time
Index: include/apr_time.h
===================================================================
RCS file: /home/cvspublic/apr/include/apr_time.h,v
retrieving revision 1.45
diff -u -u -3 -r1.45 apr_time.h
--- include/apr_time.h	13 Mar 2002 20:39:15 -0000	1.45
+++ include/apr_time.h	17 Mar 2002 20:27:16 -0000
@@ -175,7 +175,7 @@
  * @param result the resulting imploded time
  * @param input the input exploded time
  */
-APR_DECLARE(apr_status_t) apr_implode_time(apr_time_t *result, 
+APR_DECLARE(apr_status_t) apr_time_exp_get(apr_time_t *result, 
                                            apr_time_exp_t *input);
 
 /**
Index: test/testtime.c
===================================================================
RCS file: /home/cvspublic/apr/test/testtime.c,v
retrieving revision 1.28
diff -u -u -3 -r1.28 testtime.c
--- test/testtime.c	13 Mar 2002 20:39:28 -0000	1.28
+++ test/testtime.c	17 Mar 2002 20:27:18 -0000
@@ -87,7 +87,7 @@
     
     STD_TEST_NEQ("    apr_explode_localtime", apr_explode_localtime(&xt2, now))
 
-    STD_TEST_NEQ("    apr_implode_time (GMT)", apr_implode_time(&imp, &xt))
+    STD_TEST_NEQ("    apr_time_exp_get (GMT)", apr_time_exp_get(&imp, &xt))
 
     printf("%-60s", "    checking GMT explode == implode");
     if (imp != now) {
@@ -166,8 +166,8 @@
              strcmp(str, str2), 0, "OK", "Failed")
     printf("        ( %s != %s )\n", str, str2);
 
-    STD_TEST_NEQ("    apr_implode_time (offset)",
-                 apr_implode_time(&imp, &xt2))
+    STD_TEST_NEQ("    apr_time_exp_get (offset)",
+                 apr_time_exp_get(&imp, &xt2))
    
     hr_off_64 = (apr_int64_t) hr_off * APR_USEC_PER_SEC; /* microseconds */ 
     printf("%-60s","    Checking offset is correct");
Index: time/unix/time.c
===================================================================
RCS file: /home/cvspublic/apr/time/unix/time.c,v
retrieving revision 1.62
diff -u -u -3 -r1.62 time.c
--- time/unix/time.c	13 Mar 2002 20:39:31 -0000	1.62
+++ time/unix/time.c	17 Mar 2002 20:27:25 -0000
@@ -170,7 +170,7 @@
 #endif /* __EMX__ */
 }
 
-APR_DECLARE(apr_status_t) apr_implode_time(apr_time_t *t, apr_time_exp_t *xt)
+APR_DECLARE(apr_status_t) apr_time_exp_get(apr_time_t *t, apr_time_exp_t *xt)
 {
     int year;
     time_t days;
@@ -203,7 +203,7 @@
 
 APR_DECLARE(apr_status_t) apr_implode_gmt(apr_time_t *t, apr_time_exp_t *xt)
 {
-    apr_status_t status = apr_implode_time(t, xt);
+    apr_status_t status = apr_time_exp_get(t, xt);
     if (status == APR_SUCCESS)
         *t -= (apr_time_t) xt->tm_gmtoff * APR_USEC_PER_SEC;
     return status;
Index: time/win32/time.c
===================================================================
RCS file: /home/cvspublic/apr/time/win32/time.c,v
retrieving revision 1.28
diff -u -u -3 -r1.28 time.c
--- time/win32/time.c	13 Mar 2002 20:39:31 -0000	1.28
+++ time/win32/time.c	17 Mar 2002 20:27:33 -0000
@@ -185,7 +185,7 @@
     return APR_SUCCESS;
 }
 
-APR_DECLARE(apr_status_t) apr_implode_time(apr_time_t *t,
+APR_DECLARE(apr_status_t) apr_time_exp_get(apr_time_t *t,
                                            apr_time_exp_t *xt)
 {
     int year;
@@ -223,7 +223,7 @@
 APR_DECLARE(apr_status_t) apr_implode_gmt(apr_time_t *t,
                                           apr_time_exp_t *xt)
 {
-    apr_status_t status = apr_implode_time(t, xt);
+    apr_status_t status = apr_time_exp_get(t, xt);
     if (status == APR_SUCCESS)
         *t -= (apr_time_t) xt->tm_gmtoff * APR_USEC_PER_SEC;
     return status;


Index: misc/apr_date.c
===================================================================
RCS file: /home/cvspublic/apr-util/misc/apr_date.c,v
retrieving revision 1.10
diff -u -u -3 -r1.10 apr_date.c
--- misc/apr_date.c	13 Mar 2002 20:40:49 -0000	1.10
+++ misc/apr_date.c	17 Mar 2002 20:30:44 -0000
@@ -316,7 +316,7 @@
      */
     ds.tm_usec = 0;
     ds.tm_gmtoff = 0;
-    if (apr_implode_time(&result, &ds) != APR_SUCCESS) 
+    if (apr_time_exp_get(&result, &ds) != APR_SUCCESS) 
         return APR_DATE_BAD;
     
     return result;
@@ -602,7 +602,7 @@
         }
     }
 
     /* apr_implode_time uses tm_usec field, but it hasn't been set yet. 
      * It should be safe to just zero out this value.
      * tm_usec is the number of microseconds into the second.  HTTP only
      * cares about second granularity.
@@ -602,7 +602,7 @@
     }
 
-    /* apr_implode_time uses tm_usec field, but it hasn't been set yet. 
+    /* apr_time_exp_get uses tm_usec field, but it hasn't been set yet. 
      * It should be safe to just zero out this value.
      * tm_usec is the number of microseconds into the second.  HTTP only

RE: Renames Pending - apr_implode_time

Posted by Sander Striker <st...@apache.org>.
> From: Thom May [mailto:thom@planetarytramp.net]
> Sent: 17 March 2002 22:10

> Hi, here are the patches for apr and apr-utils to rename apr_implode_time to
> apr_time_exp_get.

Committed.  Thanks!

> Cheers,
> -Thom

Sander